@@ -11,7 +11,7 @@ use JSON::XS qw(decode_json encode_json);
 use Time::HiRes qw(gettimeofday time);
 use Data::Dumper;
 
-our $VERSION = "0.020";
+our $VERSION = "0.021";
 
 my %INFO_ROUTES = (
     version => '/version',
@@ -523,10 +523,10 @@ sub _build_multiget_uri {
     my $current_url = undef;
     foreach my $key (@$keys) {
         if (! defined $current_url) {
-            $current_url ||= $uri_base . "row=" . $key;
+            $current_url ||= $uri_base . "row=" . uri_escape($key);
         }
         else{
-            my $next_url = $current_url . '&row=' . $key;
+            my $next_url = $current_url . '&row=' . uri_escape($key);
             if (length($next_url) < 2000) {
                 $current_url = $next_url;
             }
@@ -869,7 +869,7 @@ Information on error is stored in hbase object under key last error:
 
 =head1 VERSION
 
-Current version: 0.020
+Current version: 0.021
 
 =head1 AUTHOR
 
